@@ -65,7 +65,7 @@ def D(elemento,color = "black"):#Por default se imprime en rojo, para indicar qu
     c = sympy.latex(elemento.args[1])
 
     texto = a+b+c
-    texto = texto.replace("text", Estilo)
+    #texto = texto.replace("text", Estilo)
 
     IPython.display.display(IPython.display.Latex("\\textcolor{"+color+"}{"+texto+"}"))
 
